@@ -194,6 +194,10 @@ setMethod("q.r", "DiscreteDistribution", function(object){
 
 setMethod("+", c("DiscreteDistribution","DiscreteDistribution"),
 function(e1,e2){
+            e1 <- as(e1, "LatticeDistribution")
+            e2 <- as(e2, "LatticeDistribution")
+            if(is(e1, "LatticeDistribution") & is(e2, "LatticeDistribution"))
+                return(e1 + e2)
             convolutedsupport <- rep(support(e1), each = length(support(e2))) +
                                  support(e2)
 
